"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var rxjs_1 = require("rxjs");
var AutoCompleteComponent = (function () {
    function AutoCompleteComponent() {
        this.opened = false;
        this.loading = false;
        this.searchModel = '';
    }
    AutoCompleteComponent.prototype.ngAfterViewInit = function () {
        var _this = this;
        rxjs_1.Observable.fromEvent(this.searchRef.nativeElement, 'focus')
            .debounceTime(200)
            .subscribe(function () {
            console.log('focus');
            _this.open();
        });
        rxjs_1.Observable.merge(rxjs_1.Observable.fromEvent(this.searchRef.nativeElement, 'blur'), rxjs_1.Observable.fromEvent(this.dropRef.nativeElement, 'click'))
            .debounceTime(210)
            .subscribe(function (e) {
            console.log('blur');
            if (e instanceof FocusEvent) {
                _this.cancel();
            }
        });
        var inputObs = rxjs_1.Observable.merge(rxjs_1.Observable.fromEvent(this.searchRef.nativeElement, 'focus'), rxjs_1.Observable.fromEvent(this.searchRef.nativeElement, 'input'), rxjs_1.Observable.fromEvent(this.searchRef.nativeElement, 'click'))
            .map(function (e) {
            console.log('input');
            return e.target.value;
        })
            .filter(function (value) {
            _this.data = [];
            var valid = value.length >= _this.minLength;
            if (valid) {
                _this.loading = true;
            }
            return valid;
        })
            .debounceTime(200)
            .subscribe(function (search) { return _this.search(search); });
    };
    AutoCompleteComponent.prototype.getCurrentText = function () {
        return this.current ? this.current.label || this.current.content : '';
    };
    AutoCompleteComponent.prototype.hasData = function () {
        return !!(this.data && this.data.length);
    };
    AutoCompleteComponent.prototype.isShowNoResult = function () {
        return !this.loading && !this.hasData() && !this.isShowInfo() && !this.current;
    };
    AutoCompleteComponent.prototype.isShowInfo = function () {
        var minLengthValid = (!this.searchModel || this.searchModel.length < this.minLength);
        return !this.loading && !this.hasData() && minLengthValid && !this.current && this.minLength !== 0;
    };
    AutoCompleteComponent.prototype.setData = function (data) {
        this.loading = false;
        this.data = data;
    };
    AutoCompleteComponent.prototype.reset = function () {
        this.model.control.setValue(null);
        this.current = null;
        this.searchModel = '';
        this.close();
    };
    AutoCompleteComponent.prototype.search = function (search) {
        var _this = this;
        if (this.sourceSubscription) {
            this.sourceSubscription.unsubscribe();
        }
        this.sourceSubscription = this.source(search).subscribe(function (data) {
            _this.setData(_this.map(data));
            _this.open();
        });
    };
    AutoCompleteComponent.prototype.select = function (row) {
        if (row.selectable !== false) {
            this.cancel();
            if (row) {
                this.model.control.setValue(row.id);
                this.current = row;
            }
        }
        return false;
    };
    AutoCompleteComponent.prototype.open = function () {
        if (!this.current) {
            this.opened = true;
        }
    };
    AutoCompleteComponent.prototype.close = function (clear) {
        this.opened = false;
        if (clear) {
            this.setData([]);
        }
    };
    AutoCompleteComponent.prototype.cancel = function () {
        if (this.sourceSubscription) {
            this.sourceSubscription.unsubscribe();
        }
        this.close(true);
        this.searchModel = '';
    };
    return AutoCompleteComponent;
}());
AutoCompleteComponent.decorators = [
    { type: core_1.Component, args: [{
                templateUrl: './autocomplete.html'
            },] },
];
/** @nocollapse */
AutoCompleteComponent.ctorParameters = function () { return []; };
AutoCompleteComponent.propDecorators = {
    'wrapperRef': [{ type: core_1.ViewChild, args: ['wrapper',] },],
    'searchRef': [{ type: core_1.ViewChild, args: ['search',] },],
    'dropRef': [{ type: core_1.ViewChild, args: ['drop',] },],
};
exports.AutoCompleteComponent = AutoCompleteComponent;
//# sourceMappingURL=autocomplete.component.js.map